//
//  NSBezierPath-NoodleExtensions.h
//  Hazel
//
//  Created by Paul Kim on 2/18/06.
//  Copyright 2006 Paul Kim d/b/a Noodlesoft. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in 
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
// IN THE SOFTWARE.

#import <Cocoa/Cocoa.h>


@interface NSBezierPath (NoodleGradient)

/*!
 @method	 gradientFillAtAngle:startColor:endColor:
 @abstract	 Paints the region enclosed by the receiver's path with a gradient at the specified angle to the path.
 @param		 angle Specifies the direction of the gradient in relation to the path, measured in degrees counterclockwise from the x-axis.
 @param		 startColor Specifies the starting color of the gradient.
 @param		 endColor Specifies the ending color of the gradient.
 @discussion This method fills the receiver's path using a gradient. The gradient will start with <i>startColor</i> and end with <i>endColor</i> with a continuous blend in between. The angle specifies the direction of the gradient with an angle of 0 indicating a gradient from left to right.
 
	Note that the length of the gradient may vary with angle as this method fits the gradient to ensure that the start and end colors are not clipped because of path geometry.
*/
- (void)gradientFillAtAngle:(float)angle startColor:(NSColor *)startColor endColor:(NSColor *)endColor;

/*!
 @method	 gradientFillWithStartPoint:endPoint:startColor:endColor:
 @abstract	 Paints the region enclosed by the receiver's path with a gradient.
 @param		 startPoint Specifies the starting point of the gradient. This point does not need to lie in or on the path.
 @param		 endPoint Specifies the ending point of the gradient. This point does not need to lie in or on the path.
 @param		 startColor Specifies the starting color of the gradient.
 @param		 endColor Specifies the ending color of the gradient.
 @discussion This method fills the receiver's path using a gradient. The gradient will start with <i>startColor</i> and end with <i>endColor</i> with a continuous blend in between. The start and end points determine the direction of the gradient. Neither the start or end points need to be in or on the receiver's path. If a point is outside the path, then it will be clipped an only an intermediate part of the gradient will be seen. If the point is inside the path, then the gradient will extend beyond that point, using the last color used in the gradient.
 */
- (void)gradientFillWithStartPoint:(NSPoint)startPoint endPoint:(NSPoint)endPoint startColor:(NSColor *)startColor endColor:(NSColor *)endColor;

@end
